Crate vfs_kit

Crate vfs_kit 

Structs

DirFS

Traits

FsBackend
FsBackend defines a common API for all virtual file systems (vfs) in the crate. Some functions here use path as a parameter or return value. In all cases, path will refer to the virtual file system. The exception is the root() function, which returns the path in the host file system.

Type Aliases

Result